
pdfslash
========

This Python program helps batch-edit PDF page margins.

For details, see `documentation <http://pdfslash.readthedocs.io/>`__.


License
-------

The software is licensed under The MIT License. See `LICENSE`_.

.. _LICENSE: https://github.com/openandclose/pdfslash/blob/master/LICENSE
